==> haskell-th-desugar-1.9-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-desugar
version: 1.9
id: th-desugar-1.9-BNwiPsmEDwg6xnlZ9tqlJF
key: th-desugar-1.9-BNwiPsmEDwg6xnlZ9tqlJF
license: BSD-3-Clause
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Richard Eisenberg <rae@cs.brynmawr.edu>
stability: experimental
homepage: https://github.com/goldfirere/th-desugar
synopsis: Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.
category: Template Haskell
abi: 7f86cc070e06d76b3bec365a829a3c14
exposed: True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten
hidden-modules: Language.Haskell.TH.Desugar.AST
                Language.Haskell.TH.Desugar.Core Language.Haskell.TH.Desugar.Match
                Language.Haskell.TH.Desugar.Util Language.Haskell.TH.Desugar.Reify
import-dirs: /usr/lib/ghc-8.6.1/site-local/th-desugar-1.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/th-desugar-1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/th-desugar-1.9
hs-libraries: HSth-desugar-1.9-BNwiPsmEDwg6xnlZ9tqlJF
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    th-expand-syns-0.4.4.0-Jqd7PPo0b5AIUFZ93VfrGv
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz
    th-orphans-0.13.6-86DZdL60rjC7o7bThkRZq1
haddock-interfaces: /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html: /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-desugar-1.9-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-desugar
version: 1.9
id: th-desugar-1.9-FoAMRTsQ8lD8EN0qvEIwca
key: th-desugar-1.9-FoAMRTsQ8lD8EN0qvEIwca
license: BSD-3-Clause
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Richard Eisenberg <rae@cs.brynmawr.edu>
stability: experimental
homepage: https://github.com/goldfirere/th-desugar
synopsis: Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.
category: Template Haskell
abi: 68cc9c565dfca0ea3a7deb2bcd07561f
exposed: True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten
hidden-modules: Language.Haskell.TH.Desugar.AST
                Language.Haskell.TH.Desugar.Core Language.Haskell.TH.Desugar.Match
                Language.Haskell.TH.Desugar.Util Language.Haskell.TH.Desugar.Reify
import-dirs: /usr/lib/ghc-8.6.1/site-local/th-desugar-1.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/th-desugar-1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/th-desugar-1.9
hs-libraries: HSth-desugar-1.9-FoAMRTsQ8lD8EN0qvEIwca
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    th-expand-syns-0.4.4.0-Jqd7PPo0b5AIUFZ93VfrGv
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz
    th-orphans-0.13.6-2VUYwcPbdL13w7ritH9a94
haddock-interfaces: /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html: /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
